Test Select

Test Multiple Select
open | ../tests/html/test_multiselect.html |
assertSelectedLabels | theSelect | Second Option

Select a single element (replaces existing selection)

select | theSelect | index=4
verifySelectedLabels | theSelect | Fifth Option

Select additional elements

addSelection | theSelect | Third Option
addSelection | theSelect | value=
verifySelectedLabels | theSelect | Third Option,Fifth Option,Empty Value Option
removeSelection | theSelect | id=o7
verifySelectedLabels | theSelect | Third Option,Fifth Option
removeSelection | theSelect | label=Fifth Option
verifySelected | theSelect | Third Option
addSelection | theSelect |
verifySelectedLabels | theSelect | Third Option,
removeSelection | theSelect |
removeSelection | theSelect | Third Option
assertFailureOnNext | No option selected |
verifySelected | theSelect |
assertFailureOnNext | No option selected |
verifySelectedLabels | theSelect |
verifyValue | theSelect |
verifyNotSomethingSelected | theSelect |
addSelection | theSelect | Third Option
addSelection | theSelect | value=
removeAllSelections | theSelect |
verifyNotSomethingSelected | theSelect |